@@ -14,9 +14,9 @@ from ..models import GameFormat, GameStatus
 from ..operations import (
     safe_add_role,
     safe_channel_reply,
-    safe_create_invite,
     safe_create_voice_channel,
     safe_ensure_voice_category,
+    safe_fetch_text_channel,
     safe_fetch_user,
     safe_followup_channel,
     safe_get_partial_message,
@@ -32,7 +32,7 @@ logger = logging.getLogger(__name__)
 
 
 class LookingForGameAction(BaseAction):
-    def __init__(self, bot: SpellBot, interaction: discord.Interaction):
+    def __init__(self, bot: SpellBot, interaction: discord.Interaction) -> None:
         super().__init__(bot, interaction)
         self.settings = Settings()
 
@@ -56,6 +56,7 @@ class LookingForGameAction(BaseAction):
 
     @tracer.wrap()
     async def filter_friend_xids(self, friend_xids: list[int]) -> list[int]:
+        assert self.guild
         if friend_xids:
             friend_xids = await self.ensure_users_exist(friend_xids)
         if friend_xids:
@@ -63,6 +64,8 @@ class LookingForGameAction(BaseAction):
                 self.interaction.user.id,
                 friend_xids,
             )
+        if friend_xids:
+            friend_xids = await self.services.games.filter_pending_games(friend_xids, self.guild.id)
         return friend_xids
 
     @tracer.wrap()
@@ -81,6 +84,7 @@ class LookingForGameAction(BaseAction):
         origin = bool(message_xid is not None)
 
         if not origin:
+            assert self.interaction.guild_id is not None
             return await self.services.games.upsert(
                 guild_xid=self.interaction.guild_id,
                 channel_xid=self.channel.id,
@@ -140,13 +144,14 @@ class LookingForGameAction(BaseAction):
         seats: Optional[int] = None,
         format: Optional[int] = None,
         message_xid: Optional[int] = None,
-    ):
+    ) -> None:
         if not self.guild or not self.channel:
             # Someone tried to lfg in a Discord thread rather than in the channel itself.
-            return await safe_send_user(
+            await safe_send_user(
                 self.interaction.user,
                 "Sorry, that command is not supported in this context.",
             )
+            return
 
         # True if user clicked on a Join Game button.
         # False if user issued a /lfg command in chat.
@@ -156,21 +161,35 @@ class LookingForGameAction(BaseAction):
         actual_seats: int = await self.get_seats(format, seats)
         actual_format: int = await self.get_format(format)
 
-        if await self.services.users.is_waiting():
+        if await self.services.users.is_waiting(self.channel.id):
+            msg = "You're already in a game in this channel."
             if origin:
-                return await safe_send_user(
-                    self.interaction.user,
-                    "You're already in a game.",
-                )
-            return await safe_followup_channel(self.interaction, "You're already in a game.")
+                return await safe_send_user(self.interaction.user, msg)
+            await safe_followup_channel(self.interaction, msg)
+            return
+
+        if await self.services.users.pending_games() + 1 > self.settings.MAX_PENDING_GAMES:
+            msg = "You're in too many pending games to join another one at this time."
+            if origin:
+                return await safe_send_user(self.interaction.user, msg)
+            await safe_followup_channel(self.interaction, msg)
+            return
+
+        if await self.services.users.queued_in_another_guild(self.guild.id):
+            msg = "You're in a pending game in another server, leave that one first."
+            if origin:
+                return await safe_send_user(self.interaction.user, msg)
+            await safe_followup_channel(self.interaction, msg)
+            return
 
         friend_xids = list(map(int, re.findall(r"<@!?(\d+)>", actual_friends)))
 
         if len(friend_xids) + 1 > actual_seats:
-            return await safe_send_user(
+            await safe_send_user(
                 self.interaction.user,
                 "You mentioned too many players.",
             )
+            return
 
         friend_xids = await self.filter_friend_xids(friend_xids)
 
@@ -184,8 +203,11 @@ class LookingForGameAction(BaseAction):
             return
 
         fully_seated = await self.services.games.fully_seated()
+        started_game_id: Optional[int] = None
+        other_game_ids: list[int] = []
         if fully_seated:
-            await self._handle_link_creation()
+            other_game_ids = await self.services.games.other_game_ids()
+            started_game_id = await self.make_game_ready()
             await self._handle_voice_creation(self.guild.id)
 
         await self._handle_embed_creation(
@@ -195,37 +217,69 @@ class LookingForGameAction(BaseAction):
         )
 
         if fully_seated:
-            await self.services.games.record_plays()
+            assert started_game_id is not None
             await self._handle_direct_messages()
+            await self._update_other_game_posts(other_game_ids)
 
     @tracer.wrap()
-    async def add_points(self, message: Message, points: int):
+    async def _update_other_game_posts(self, other_game_ids: list[int]) -> None:
+        """Update any other pending games to show that some players are no longer available."""
+        assert self.channel is not None
+        assert self.guild is not None
+        if not other_game_ids:
+            return
+
+        message_xids = await self.services.games.message_xids(other_game_ids)
+        for message_xid in message_xids:
+            data = await self.services.games.select_by_message_xid(message_xid)
+            if not data:
+                continue
+
+            channel_xid = data["channel_xid"]
+            guild_xid = data["guild_xid"]
+            if channel := await safe_fetch_text_channel(self.bot, guild_xid, channel_xid):
+                if message := safe_get_partial_message(
+                    channel,
+                    guild_xid,
+                    message_xid,
+                ):
+                    embed = await self.services.games.to_embed()
+                    await safe_update_embed(
+                        message,
+                        embed=embed,
+                        view=PendingGameView(bot=self.bot),
+                    )
+
+    @tracer.wrap()
+    async def add_points(self, message: Message, points: int) -> None:
         found = await self.services.games.select_by_message_xid(message.id)
         if not found:
             return
 
         if not await self.services.games.players_included(self.interaction.user.id):
-            return await safe_send_user(
+            await safe_send_user(
                 self.interaction.user,
                 "You are not one of the players in this game.",
             )
+            return
 
         await self.services.games.add_points(self.interaction.user.id, points)
         embed = await self.services.games.to_embed()
         await safe_update_embed(message, embed=embed)
 
     @tracer.wrap()
-    async def create_game(self, players: str, format: Optional[int] = None):
+    async def create_game(self, players: str, format: Optional[int] = None) -> None:
         assert self.channel
 
         game_format = GameFormat(format or GameFormat.COMMANDER.value)  # type: ignore
         player_xids = list(map(int, re.findall(r"<@!?(\d+)>", players)))
         requested_seats = len(player_xids)
         if requested_seats < 2 or requested_seats > game_format.players:
-            return await safe_followup_channel(
+            await safe_followup_channel(
                 self.interaction,
                 f"You can't create a {game_format} game with {requested_seats} players.",
             )
+            return
 
         found_players: list[int] = []
         found_players = await self.ensure_users_exist(player_xids, exclude_self=False)
@@ -233,13 +287,14 @@ class LookingForGameAction(BaseAction):
         if len(found_players) != requested_seats:
             excluded_player_xids = set(player_xids) - set(found_players)
             excluded_players_s = ", ".join(f"<@{xid}>" for xid in excluded_player_xids)
-            return await safe_followup_channel(
+            await safe_followup_channel(
                 self.interaction,
                 (
                     "Some of the players you mentioned can not"
                     f" be added to a game: {excluded_players_s}"
                 ),
             )
+            return
 
         assert self.interaction.guild_id
         await self.services.games.upsert(
@@ -251,19 +306,18 @@ class LookingForGameAction(BaseAction):
             format=game_format.value,
             create_new=True,
         )
-        await self._handle_link_creation()
+        await self.make_game_ready()
         await self._handle_voice_creation(self.interaction.guild_id)
         await self._handle_embed_creation(new=True, origin=False, fully_seated=True)
-        await self.services.games.record_plays()
         await self._handle_direct_messages()
 
     @tracer.wrap()
-    async def _handle_link_creation(self):
+    async def make_game_ready(self) -> int:
         spelltable_link = await self.bot.create_spelltable_link()
-        await self.services.games.make_ready(spelltable_link)
+        return await self.services.games.make_ready(spelltable_link)
 
     @tracer.wrap()
-    async def _handle_voice_creation(self, guild_xid: int):
+    async def _handle_voice_creation(self, guild_xid: int) -> None:
         if not await self.services.guilds.should_voice_create():
             return
 
@@ -286,14 +340,7 @@ class LookingForGameAction(BaseAction):
         if not voice_channel:
             return
 
-        # This can fail, but it's ok if it does, users don't NEED
-        # an invite link to find their game's voice channel.
-        voice_invite_link = await safe_create_invite(
-            voice_channel,
-            guild_xid,
-            self.settings.VOICE_INVITE_EXPIRE_TIME_S,
-        )
-        await self.services.games.set_voice(voice_channel.id, voice_invite_link)
+        await self.services.games.set_voice(voice_channel.id)
 
     @tracer.wrap()
     async def _handle_embed_creation(  # pylint: disable=too-many-branches
@@ -307,6 +354,7 @@ class LookingForGameAction(BaseAction):
 
         # build the game post's embed and view:
         embed: discord.Embed = await self.services.games.to_embed()
+        content = self.channel_data.get("extra", None)
 
         view: Optional[BaseView] = None
         if fully_seated:
@@ -316,9 +364,19 @@ class LookingForGameAction(BaseAction):
             view = PendingGameView(bot=self.bot)
 
         if new:  # create the initial game post:
-            if message := await safe_followup_channel(self.interaction, embed=embed, view=view):
+            if message := await safe_followup_channel(
+                self.interaction,
+                content=content,
+                embed=embed,
+                view=view,
+            ):
                 await self.services.games.set_message_xid(message.id)
-            elif message := await safe_channel_reply(self.channel, embed=embed, view=view):
+            elif message := await safe_channel_reply(
+                self.channel,
+                content=content,
+                embed=embed,
+                view=view,
+            ):
                 await self.services.games.set_message_xid(message.id)
             return
 
@@ -335,20 +393,31 @@ class LookingForGameAction(BaseAction):
             # If it does fail, we will fallback to doing a standard
             # message.edit() call, which should hopefully at least update
             # the game embed, even if the interaction shows as "failed".
-            if await safe_update_embed_origin(self.interaction, embed=embed, view=view):
+            content = self.channel_data.get("extra", None)
+            if await safe_update_embed_origin(
+                self.interaction,
+                content=content,
+                embed=embed,
+                view=view,
+            ):
                 return
 
         if message:
             if await safe_update_embed(message, embed=embed, view=view):
                 pass
-            elif updated := await safe_channel_reply(self.channel, embed=embed, view=view):
+            elif updated := await safe_channel_reply(
+                self.channel,
+                content=content,
+                embed=embed,
+                view=view,
+            ):
                 await self.services.games.set_message_xid(updated.id)
 
         if not origin:
             await self._reply_found_embed()
 
     @tracer.wrap()
-    async def _reply_found_embed(self):
+    async def _reply_found_embed(self) -> None:
         embed = Embed()
         embed.set_thumbnail(url=self.settings.ICO_URL)
         embed.set_author(name="I found a game for you!")
@@ -359,7 +428,7 @@ class LookingForGameAction(BaseAction):
         await safe_followup_channel(self.interaction, embed=embed)
 
     @tracer.wrap()
-    async def _handle_direct_messages(self):
+    async def _handle_direct_messages(self) -> None:
         player_xids = await self.services.games.player_xids()
         embed = await self.services.games.to_embed(dm=True)
         failed_xids: list[int] = []
@@ -375,6 +444,7 @@ class LookingForGameAction(BaseAction):
                 failed_xids.append(player_xid)
 
         # give out awards
+        assert self.interaction.guild_id is not None
         new_roles = await self.services.awards.give_awards(
             self.interaction.guild_id,
             player_xids,
@@ -409,7 +479,7 @@ class LookingForGameAction(BaseAction):
         await self._handle_watched_players(player_xids)
 
     @tracer.wrap()
-    async def _handle_watched_players(self, player_xids: list[int]):
+    async def _handle_watched_players(self, player_xids: list[int]) -> None:
         """Notify moderators about watched players."""
         assert self.interaction.guild
         mod_role: Optional[discord.Role] = None
