@@ -13,8 +13,9 @@ logger = logging.getLogger(__name__)
 
 
 class ScoreAction(BaseAction):
-    async def execute(self, target: Union[discord.Member, discord.User]):
+    async def execute(self, target: Union[discord.Member, discord.User]) -> None:
         assert self.interaction.guild
+        assert self.interaction.guild_id is not None
         guild_name = self.interaction.guild.name
         assert hasattr(target, "id")
         target_xid = target.id
@@ -33,7 +34,7 @@ class ScoreAction(BaseAction):
         embed.color = settings.EMBED_COLOR
         await safe_send_channel(self.interaction, embed=embed, ephemeral=True)
 
-    async def history(self):
+    async def history(self) -> None:
         assert self.interaction.channel
         assert hasattr(self.interaction.channel, "name")
         channel_name = self.interaction.channel.name  # type: ignore
@@ -48,7 +49,7 @@ class ScoreAction(BaseAction):
         embed.color = settings.EMBED_COLOR
         await safe_send_channel(self.interaction, embed=embed, ephemeral=True)
 
-    async def top(self, monthly: bool, ago: int):
+    async def top(self, monthly: bool, ago: int) -> None:
         if not monthly:
             ago = 0  # "months ago" doesn't make sense for "all time" range
 
@@ -58,13 +59,14 @@ class ScoreAction(BaseAction):
         channel_xid = self.interaction.channel.id
         guild_xid = self.interaction.guild_id
 
+        assert guild_xid is not None
         data = await self.services.plays.top_records(guild_xid, channel_xid, monthly, ago)
 
         settings = Settings()
         embed = discord.Embed()
         embed.set_thumbnail(url=settings.ICO_URL)
-        range = f"{ago} months ago" if ago else "this month" if monthly else "all time"
-        embed.title = f"Top players in #{channel_name} ({range})"
+        range_s = f"{ago} months ago" if ago else "this month" if monthly else "all time"
+        embed.title = f"Top players in #{channel_name} ({range_s})"
         description = ""
         description += "Rank \xa0\xa0\xa0 Games \xa0\xa0\xa0 Player\n"
         for rank, datum in enumerate(data):
