@@ -28,18 +28,21 @@ class WatchAction(BaseAction):
         target: Optional[Union[discord.User, discord.Member]] = None,
         id: Optional[int] = None,
         note: Optional[str] = None,
-    ):
+    ) -> None:
         if target:
             await self.services.users.upsert(target)
 
         target_xid: Optional[int] = None
+        assert target is not None or id is not None
         if target and hasattr(target, "id"):
             target_xid = target.id
-        elif id:
+        else:
+            assert id is not None
             target_xid = id
         assert target_xid is not None
 
         if action is ActionType.UNWATCH:
+            assert self.interaction.guild_id is not None
             await self.services.users.unwatch(self.interaction.guild_id, target_xid)
             await safe_send_channel(
                 self.interaction,
@@ -47,21 +50,20 @@ class WatchAction(BaseAction):
                 ephemeral=True,
             )
         else:
+            assert self.interaction.guild_id is not None
             await self.services.users.watch(self.interaction.guild_id, target_xid, note=note)
             await safe_send_channel(self.interaction, f"Watching <@{target_xid}>.", ephemeral=True)
 
-    async def watch(self, target: Union[discord.User, discord.Member], note: Optional[str] = None):
-        await self.execute(ActionType.WATCH, target=target, note=note)
-
-    async def unwatch(
+    async def watch(
         self,
-        target: Optional[Union[discord.User, discord.Member]] = None,
+        target: Optional[Union[discord.User, discord.Member]],
         id: Optional[str] = None,
-    ):
+        note: Optional[str] = None,
+    ) -> None:
         if not target and not id:
             await safe_send_channel(
                 self.interaction,
-                "You must provide either a target User or their ID",
+                "You must provide either a target User or their ID.",
                 ephemeral=True,
             )
             return
@@ -73,7 +75,34 @@ class WatchAction(BaseAction):
             except ValueError:
                 await safe_send_channel(
                     self.interaction,
-                    "You must provide a valid integer for an ID",
+                    "You must provide a valid integer for an ID.",
+                    ephemeral=True,
+                )
+                return
+
+        await self.execute(ActionType.WATCH, target=target, id=xid, note=note)
+
+    async def unwatch(
+        self,
+        target: Optional[Union[discord.User, discord.Member]] = None,
+        id: Optional[str] = None,
+    ) -> None:
+        if not target and not id:
+            await safe_send_channel(
+                self.interaction,
+                "You must provide either a target User or their ID.",
+                ephemeral=True,
+            )
+            return
+
+        xid: Optional[int] = None
+        if id:
+            try:
+                xid = int(id)
+            except ValueError:
+                await safe_send_channel(
+                    self.interaction,
+                    "You must provide a valid integer for an ID.",
                     ephemeral=True,
                 )
                 return
@@ -91,6 +120,7 @@ class WatchAction(BaseAction):
             return embed
 
         watches = WatchesService()
+        assert self.interaction.guild_id is not None
         entries = await watches.fetch(guild_xid=self.interaction.guild_id)
 
         embeds: list[Embed] = []
@@ -114,6 +144,6 @@ class WatchAction(BaseAction):
 
         return embeds
 
-    async def watched(self, page: int):
+    async def watched(self, page: int) -> None:
         embeds: list[Embed] = await self.get_watched_embeds()
         await safe_send_channel(self.interaction, embed=embeds[page - 1])
