@@ -14,6 +14,7 @@ from expiringdict import ExpiringDict
 
 from .database import db_session_manager, initialize_connection
 from .metrics import setup_ignored_errors, setup_metrics
+from .operations import safe_delete_message
 from .services import ChannelsService, GamesService, GuildsService, VerifiesService
 from .settings import Settings
 from .spelltable import generate_link
@@ -27,7 +28,7 @@ class SpellBot(AutoShardedBot):
         self,
         mock_games: bool = False,
         create_connection: bool = True,
-    ):
+    ) -> None:
         self.settings = Settings()
         intents = discord.Intents().default()
         intents.members = True  # pylint: disable=E0237
@@ -42,12 +43,15 @@ class SpellBot(AutoShardedBot):
         )
         self.mock_games = mock_games
         self.create_connection = create_connection
-        self.channel_locks = ExpiringDict(max_len=100, max_age_seconds=3600)  # 1 hr
+        self.guild_locks = ExpiringDict(max_len=100, max_age_seconds=3600)  # 1 hr
 
-    async def on_ready(self):
+    async def on_ready(self) -> None:  # pragma: no cover
         logger.info("client ready")
 
-    async def setup_hook(self) -> None:
+    async def on_shard_ready(self, shard_id: int) -> None:  # pragma: no cover
+        logger.info(f"shard {shard_id} ready")
+
+    async def setup_hook(self) -> None:  # pragma: no cover
         # Note: In tests we create the connection using fixtures.
         if self.create_connection:  # pragma: no cover
             logger.info("initializing database connection...")
@@ -66,10 +70,10 @@ class SpellBot(AutoShardedBot):
         await load_extensions(self)
 
     @asynccontextmanager
-    async def channel_lock(self, channel_xid: int) -> AsyncGenerator[None, None]:
-        if not self.channel_locks.get(channel_xid):
-            self.channel_locks[channel_xid] = asyncio.Lock()
-        async with self.channel_locks[channel_xid]:  # type: ignore
+    async def guild_lock(self, guild_xid: int) -> AsyncGenerator[None, None]:
+        if not self.guild_locks.get(guild_xid):
+            self.guild_locks[guild_xid] = asyncio.Lock()
+        async with self.guild_locks[guild_xid]:  # type: ignore
             yield
 
     @tracer.wrap()
@@ -79,21 +83,24 @@ class SpellBot(AutoShardedBot):
         return await generate_link()
 
     @tracer.wrap(name="interaction", resource="on_message")
-    async def on_message(self, message: discord.Message):  # pylint: disable=arguments-differ
+    async def on_message(  # pylint: disable=arguments-differ
+        self,
+        message: discord.Message,
+    ) -> None:
         span = tracer.current_span()
-        if span:  # noqa
+        if span:
             setup_ignored_errors(span)
 
         # handle DMs normally
         if not message.guild or not hasattr(message.guild, "id"):
             return await super().on_message(message)
-        if span:  # noqa
+        if span:
             span.set_tag("guild_id", message.guild.id)  # type: ignore
 
         # ignore everything except messages in text channels
         if not hasattr(message.channel, "type") or message.channel.type != discord.ChannelType.text:
             return
-        if span:  # noqa
+        if span:
             span.set_tag("channel_id", message.channel.id)  # type: ignore
 
         # ignore hidden/ephemeral messages
@@ -105,7 +112,7 @@ class SpellBot(AutoShardedBot):
             return
 
         message_author_xid = message.author.id  # type: ignore
-        if span:  # noqa
+        if span:
             span.set_tag("author_id", message_author_xid)
 
         # don't try to verify the bot itself
@@ -133,10 +140,11 @@ class SpellBot(AutoShardedBot):
         return await super().on_command_error(context, exception)
 
     @tracer.wrap()
-    async def handle_verification(self, message: discord.Message):
+    async def handle_verification(self, message: discord.Message) -> None:
         message_author_xid = message.author.id  # type: ignore
         verified: Optional[bool] = None
         guilds = GuildsService()
+        assert message.guild is not None
         await guilds.upsert(message.guild)
         channels = ChannelsService()
         channel_data = await channels.upsert(message.channel)
@@ -149,12 +157,12 @@ class SpellBot(AutoShardedBot):
         if not user_can_moderate(message.author, guild, message.channel):
             user_is_verified = await verify.is_verified()
             if user_is_verified and channel_data["unverified_only"]:
-                await message.delete()
+                await safe_delete_message(message)
             if not user_is_verified and channel_data["verified_only"]:
-                await message.delete()
+                await safe_delete_message(message)
 
     @tracer.wrap()
-    async def handle_message_deleted(self, message: discord.Message):
+    async def handle_message_deleted(self, message: discord.Message) -> None:
         games = GamesService()
         data = await games.select_by_message_xid(message.id)
         if not data:
