@@ -41,14 +41,13 @@ __all__ = [
 ]
 
 
-async def load_all_cogs(bot: AutoShardedBot) -> AutoShardedBot:
+async def load_all_cogs(bot: AutoShardedBot) -> AutoShardedBot:  # pragma: no cover
     # iterate through the modules in the current package
     package_dir = Path(__file__).resolve().parent
     for info in iter_modules([str(package_dir)]):
-
         # import the module and iterate through its attributes
         module = import_module(f"{__name__}.{info.name}")
-        for attribute_name in dir(module):  # pragma: no cover
+        for attribute_name in dir(module):
             attribute = getattr(module, attribute_name)
 
             # Only load cogs in this module if they're exported
