@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 @for_all_callbacks(app_commands.check(is_admin))
 @for_all_callbacks(app_commands.check(is_guild))
 class AdminCog(commands.Cog):
-    def __init__(self, bot: SpellBot):
+    def __init__(self, bot: SpellBot) -> None:
         self.bot = bot
 
     @app_commands.command(name="setup", description="Setup SpellBot on your server.")
@@ -64,6 +64,20 @@ class AdminCog(commands.Cog):
         async with AdminAction.create(self.bot, interaction) as action:
             await action.set_channel_motd(message)
 
+    @set_group.command(
+        name="channel_extra",
+        description="Set this channel's extra message. Leave blank to unset.",
+    )
+    @tracer.wrap(name="interaction", resource="set_channel_extra")
+    async def channel_extra(
+        self,
+        interaction: discord.Interaction,
+        message: Optional[str] = None,
+    ) -> None:
+        add_span_context(interaction)
+        async with AdminAction.create(self.bot, interaction) as action:
+            await action.set_channel_extra(message)
+
     @app_commands.command(
         name="channels",
         description="Show the current configurations for channels on your server.",
@@ -223,5 +237,5 @@ class AdminCog(commands.Cog):
             await action.set_show_points(setting)
 
 
-async def setup(bot: SpellBot):  # pragma: no cover
+async def setup(bot: SpellBot) -> None:  # pragma: no cover
     await bot.add_cog(AdminCog(bot), guild=bot.settings.GUILD_OBJECT)
