@@ -11,6 +11,7 @@ from .. import SpellBot
 from ..actions import LookingForGameAction
 from ..metrics import add_span_context
 from ..models import GameFormat
+from ..operations import safe_defer_interaction
 from ..utils import for_all_callbacks, is_admin, is_guild
 
 logger = logging.getLogger(__name__)
@@ -19,7 +20,7 @@ logger = logging.getLogger(__name__)
 @for_all_callbacks(app_commands.check(is_admin))
 @for_all_callbacks(app_commands.check(is_guild))
 class EventsCog(commands.Cog):
-    def __init__(self, bot: SpellBot):
+    def __init__(self, bot: SpellBot) -> None:
         self.bot = bot
 
     @app_commands.command(name="game", description="Immediately create and start an ad-hoc game.")
@@ -37,10 +38,10 @@ class EventsCog(commands.Cog):
     ) -> None:
         assert interaction.channel_id is not None
         add_span_context(interaction)
-        await interaction.response.defer()
+        await safe_defer_interaction(interaction)
         async with LookingForGameAction.create(self.bot, interaction) as action:
             await action.create_game(players, format)
 
 
-async def setup(bot: SpellBot):  # pragma: no cover
+async def setup(bot: SpellBot) -> None:  # pragma: no cover
     await bot.add_cog(EventsCog(bot), guild=bot.settings.GUILD_OBJECT)
