@@ -11,6 +11,7 @@ from .. import SpellBot
 from ..actions.lfg_action import LookingForGameAction
 from ..metrics import add_span_context
 from ..models import GameFormat
+from ..operations import safe_defer_interaction
 from ..utils import for_all_callbacks, is_guild
 
 logger = logging.getLogger(__name__)
@@ -18,7 +19,7 @@ logger = logging.getLogger(__name__)
 
 @for_all_callbacks(app_commands.check(is_guild))
 class LookingForGameCog(commands.Cog):
-    def __init__(self, bot: SpellBot):
+    def __init__(self, bot: SpellBot) -> None:
         self.bot = bot
 
     @app_commands.command(name="lfg", description="Looking for game.")
@@ -42,14 +43,14 @@ class LookingForGameCog(commands.Cog):
         friends: Optional[str] = None,
         seats: Optional[int] = None,
         format: Optional[int] = None,
-    ):
-        assert interaction.channel_id is not None
+    ) -> None:
+        assert interaction.guild is not None
         add_span_context(interaction)
-        await interaction.response.defer()
-        async with self.bot.channel_lock(interaction.channel_id):
+        await safe_defer_interaction(interaction)
+        async with self.bot.guild_lock(interaction.guild.id):
             async with LookingForGameAction.create(self.bot, interaction) as action:
                 await action.execute(friends=friends, seats=seats, format=format)
 
 
-async def setup(bot: SpellBot):  # pragma: no cover
+async def setup(bot: SpellBot) -> None:  # pragma: no cover
     await bot.add_cog(LookingForGameCog(bot), guild=bot.settings.GUILD_OBJECT)
