@@ -6,7 +6,7 @@ import coloredlogs
 
 
 # Note: be sure to call this before importing any application modules!
-def configure_logging(level: Union[int, str]):  # pragma: no cover
+def configure_logging(level: Union[int, str]) -> None:  # pragma: no cover
     coloredlogs.install(
         level=level,
         fmt="[%(asctime)s][%(name)s][%(levelname)s] - %(message)s",
