@@ -30,14 +30,14 @@ FormatDetails = namedtuple("FormatDetails", ["players"])
 class GameFormat(Enum):
     """A Magic: The Gathering game format."""
 
-    def __new__(cls, *args: Any, **kwargs: Any):  # pylint: disable=W0613
+    def __new__(cls, *args: Any, **kwargs: Any) -> Any:  # pylint: disable=W0613
         """Give each enum value an increasing numerical value starting at 1."""
         value = len(cls.__members__) + 1
         obj = object.__new__(cls)
         obj._value_ = value
         return obj
 
-    def __init__(self, players: int):
+    def __init__(self, players: int) -> None:
         """Each enum has certain additional properties taken from FormatDetails."""
         self.players = players
 
@@ -157,12 +157,6 @@ class Game(Base):
         doc="The generate voice channel invite link for this game",
     )
 
-    players = relationship(
-        "User",
-        back_populates="game",
-        uselist=True,
-        doc="Players in this game",
-    )
     guild = relationship(
         "Guild",
         back_populates="games",
@@ -174,6 +168,24 @@ class Game(Base):
         doc="The channel this game was created in",
     )
 
+    @property
+    def players(self) -> list[User]:
+        from ..database import DatabaseSession
+        from . import User
+
+        return DatabaseSession.query(User).filter(User.xid.in_(self.player_xids)).all()
+
+    @property
+    def player_xids(self) -> list[int]:
+        from ..database import DatabaseSession
+        from . import Play, Queue
+
+        if self.started_at is None:
+            rows = DatabaseSession.query(Queue.user_xid).filter(Queue.game_id == self.id)
+        else:
+            rows = DatabaseSession.query(Play.user_xid).filter(Play.game_id == self.id)
+        return [int(row[0]) for row in rows]
+
     @property
     def started_at_timestamp(self) -> int:
         assert self.started_at is not None
@@ -207,13 +219,8 @@ class Game(Base):
                         " for this game. Please go to [SpellTable]"
                         "(https://spelltable.wizards.com/) to create one."
                     )
-                if self.voice_invite_link:
-                    settings = Settings()
-                    expire_min = int(settings.VOICE_INVITE_EXPIRE_TIME_S / 60)
-                    description += (
-                        f"\n\n[Join your voice chat now!]({self.voice_invite_link})"
-                        f" (invite will expire in {expire_min} minutes)"
-                    )
+                if self.voice_xid:
+                    description += f"\n\nJoin your voice chat now: <#{self.voice_xid}>"
             else:
                 description += "Please check your Direct Messages for your SpellTable link."
             if dm:
@@ -223,12 +230,33 @@ class Game(Base):
                 )
             elif self.channel.show_points:
                 description += "\n\nWhen your game is over use the drop down to report your points."
+        placeholders = self.placeholders
         if self.guild.motd:
-            description += f"\n\n{self.guild.motd}"
+            description += f"\n\n{self.apply_placeholders(placeholders, self.guild.motd)}"
         if self.channel.motd:
-            description += f"\n\n{self.channel.motd}"
+            description += f"\n\n{self.apply_placeholders(placeholders, self.channel.motd)}"
         return description
 
+    @property
+    def placeholders(self) -> dict[str, str]:
+        if self.started_at:
+            game_start = f"<t:{self.started_at_timestamp}>"
+        else:
+            game_start = "pending"
+        placeholders = {
+            "game_id": str(self.id),
+            "game_format": self.format_name,
+            "game_start": game_start,
+        }
+        for i, player in enumerate(self.players):
+            placeholders[f"player_name_{i+1}"] = player.name
+        return placeholders
+
+    def apply_placeholders(self, placeholders: dict[str, str], text: str) -> str:
+        for k, v in placeholders.items():
+            text = text.replace(f"${{{k}}}", v)
+        return text
+
     @property
     def embed_players(self) -> str:
         player_strs: list[str] = []
@@ -266,10 +294,11 @@ class Game(Base):
 
     @property
     def format_name(self) -> str:
-        return GameFormat(self.format).name.replace("_", " ").title()
+        format = GameFormat(self.format)  # type: ignore
+        return format.name.replace("_", " ").title()
 
     def to_embed(self, dm: bool = False) -> discord.Embed:
-        settings = Settings(self.guild_xid)
+        settings = Settings(self.guild_xid)  # type: ignore
         embed = discord.Embed(title=self.embed_title)
         embed.set_thumbnail(url=settings.THUMB_URL)
         embed.description = self.embed_description(dm)
@@ -278,8 +307,6 @@ class Game(Base):
         embed.add_field(name="Format", value=self.format_name)
         if self.started_at:
             embed.add_field(name="Started at", value=f"<t:{self.started_at_timestamp}>")
-        if self.voice_xid and self.show_links(dm):
-            embed.add_field(name="Voice Channel", value=f"<#{self.voice_xid}>")
         embed.set_footer(text=self.embed_footer)
         embed.color = discord.Color(settings.EMBED_COLOR)
         return embed
@@ -300,6 +327,5 @@ class Game(Base):
             "format": self.format,
             "spelltable_link": self.spelltable_link,
             "spectate_link": self.spectate_link,
-            "voice_invite_link": self.voice_invite_link,
             "jump_link": self.jump_link,
         }
