@@ -1,9 +1,11 @@
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, Any, Optional, Union, cast
+from asyncio import sleep
+from typing import TYPE_CHECKING, Any, Awaitable, Callable, Optional, Union, cast
 
 import discord
+from aiohttp.client_exceptions import ClientOSError
 from ddtrace import tracer
 from discord.errors import DiscordException
 from discord.utils import MISSING
@@ -12,6 +14,7 @@ from .metrics import add_span_error
 from .utils import (
     CANT_SEND_CODE,
     bot_can_delete_channel,
+    bot_can_manage_channels,
     bot_can_read,
     bot_can_reply_to,
     bot_can_role,
@@ -25,13 +28,51 @@ if TYPE_CHECKING:
     from discord.guild import GuildChannel
     from discord.threads import Thread
 
-    # Good god why does discord.py type hinting suck so much ass?
     GetChannelReturnType = Optional[Union[GuildChannel, Thread, PrivateChannel]]
 
 logger = logging.getLogger(__name__)
 bad_users: set[int] = set()
 
 
+@tracer.wrap()
+async def retry(func: Callable[[], Awaitable[Any]]) -> Any:
+    times = 0
+    while True:
+        try:
+            times += 1
+            return await func()
+        except ClientOSError:
+            if times > 3:
+                raise
+            await sleep(times / 100)  # 10ms, 20ms, 30ms, etc.
+
+
+@tracer.wrap()
+async def safe_original_response(
+    interaction: discord.Interaction,
+) -> Optional[discord.InteractionMessage]:
+    response: Optional[discord.InteractionMessage] = None
+    with suppress(
+        DiscordException,
+        ClientOSError,
+        log="could fetch original response for user %(user_xid)s",
+        user_xid=interaction.user.id,
+    ):
+        response = await retry(lambda: interaction.original_response())
+    return response
+
+
+@tracer.wrap()
+async def safe_defer_interaction(interaction: discord.Interaction) -> None:
+    with suppress(
+        DiscordException,
+        ClientOSError,
+        log="could defer interaction for user %(user_xid)s",
+        user_xid=interaction.user.id,
+    ):
+        await retry(lambda: interaction.response.defer())
+
+
 @tracer.wrap()
 async def safe_fetch_user(
     client: discord.Client,
@@ -46,10 +87,11 @@ async def safe_fetch_user(
 
     with suppress(
         DiscordException,
+        ClientOSError,
         log="could not fetch user %(user_xid)s",
         user_xid=user_xid,
     ):
-        user = await client.fetch_user(user_xid)
+        user = await retry(lambda: client.fetch_user(user_xid))
     return user
 
 
@@ -67,10 +109,11 @@ async def safe_fetch_guild(
 
     with suppress(
         DiscordException,
+        ClientOSError,
         log="could not fetch guild %(guild_xid)s",
         guild_xid=guild_xid,
     ):
-        guild = await client.fetch_guild(guild_xid)
+        guild = await retry(lambda: client.fetch_guild(guild_xid))
     return guild
 
 
@@ -83,26 +126,24 @@ async def safe_fetch_text_channel(
     if span := tracer.current_span():  # pragma: no cover
         span.set_tags({"guild_xid": str(guild_xid), "channel_xid": str(channel_xid)})
 
-    # first check our channel cache
-    channel: GetChannelReturnType
-    if channel := client.get_channel(channel_xid):
-        if not isinstance(channel, discord.TextChannel):
+    if got := client.get_channel(channel_xid):
+        if not isinstance(got, discord.TextChannel):
             return None
-        return channel
+        return got
 
-    # fallback to hitting the Discord API
+    channel: Optional[discord.TextChannel] = None
     with suppress(
         DiscordException,
+        ClientOSError,
         log="in guild %(guild_xid)s, could not fetch channel %(channel_xid)s",
         guild_xid=guild_xid,
         channel_xid=channel_xid,
     ):
-        fetched = await client.fetch_channel(channel_xid)
+        fetched = await retry(lambda: client.fetch_channel(channel_xid))
         if isinstance(fetched, discord.TextChannel):
-            return fetched
+            channel = fetched
 
-    # failed to find in cache or via the API
-    return None
+    return channel
 
 
 @tracer.wrap()
@@ -124,6 +165,7 @@ def safe_get_partial_message(
     text_channel = cast(discord.TextChannel, channel)
     with suppress(
         DiscordException,
+        ClientOSError,
         log="in guild %(guild_xid)s, could not get partial message %(message_xid)s",
         guild_xid=guild_xid,
         message_xid=message_xid,
@@ -144,11 +186,12 @@ async def safe_update_embed(
     updated_message: Optional[discord.Message] = None
     with suppress(
         DiscordException,
+        ClientOSError,
         log="could not update embed in message %(message_xid)s",
         message_xid=message.id,
     ):
         try:
-            updated_message = await message.edit(*args, **kwargs)
+            updated_message = await retry(lambda: message.edit(*args, **kwargs))
         except discord.errors.NotFound:
             guild_xid = message.guild.id if message.guild else None
             logger.warning("in guild %s, unknown message %s", guild_xid, message.id)
@@ -163,10 +206,11 @@ async def safe_delete_message(message: Union[discord.Message, discord.PartialMes
     success: bool = False
     with suppress(
         DiscordException,
+        ClientOSError,
         log="could not delete message %(message_xid)s",
         message_xid=message.id,
     ):
-        await message.delete()
+        await retry(lambda: message.delete())
         success = True
     return success
 
@@ -186,10 +230,11 @@ async def safe_update_embed_origin(
     success: bool = False
     with suppress(
         DiscordException,
+        ClientOSError,
         log="could not update origin embed in message %(message_xid)s",
         message_xid=interaction.message.id,
     ):
-        await interaction.edit_original_response(*args, **kwargs)
+        await retry(lambda: interaction.edit_original_response(*args, **kwargs))
         success = True
     return success
 
@@ -204,16 +249,20 @@ async def safe_create_category_channel(
         span.set_tags({"guild_xid": str(guild_xid), "name": name})
 
     guild: Optional[discord.Guild]
-    if not (guild := await safe_fetch_guild(client, guild_xid)):
+    if not (guild := await retry(lambda: safe_fetch_guild(client, guild_xid))):
+        return None
+
+    if not bot_can_manage_channels(guild):
         return None
 
     channel: Optional[discord.CategoryChannel] = None
     with suppress(
         DiscordException,
+        ClientOSError,
         log="in guild %(guild_xid)s, could not create category channel",
         guild_xid=guild_xid,
     ):
-        channel = await guild.create_category_channel(name)
+        channel = await retry(lambda: guild.create_category_channel(name))
     return channel
 
 
@@ -228,16 +277,17 @@ async def safe_create_voice_channel(
         span.set_tags({"guild_xid": str(guild_xid), "name": name})
 
     guild: Optional[discord.Guild]
-    if not (guild := await safe_fetch_guild(client, guild_xid)):
+    if not (guild := await retry(lambda: safe_fetch_guild(client, guild_xid))):
         return None
 
     channel: Optional[discord.VoiceChannel] = None
     with suppress(
         DiscordException,
+        ClientOSError,
         log="in guild %(guild_xid)s, could not create voice channel",
         guild_xid=guild_xid,
     ):
-        channel = await guild.create_voice_channel(name, category=category)
+        channel = await retry(lambda: guild.create_voice_channel(name, category=category))
     return channel
 
 
@@ -251,7 +301,7 @@ async def safe_ensure_voice_category(
         span.set_tags({"guild_xid": str(guild_xid), "prefix": prefix})
 
     guild: Optional[discord.Guild]
-    if not (guild := await safe_fetch_guild(client, guild_xid)):
+    if not (guild := await retry(lambda: safe_fetch_guild(client, guild_xid))):
         return None
 
     def category_num(cat: discord.CategoryChannel) -> int:
@@ -285,34 +335,15 @@ async def safe_ensure_voice_category(
     if available:
         return available
 
-    return await safe_create_category_channel(
-        client,
-        guild_xid,
-        category_name(len(full)),
+    return await retry(
+        lambda: safe_create_category_channel(
+            client,
+            guild_xid,
+            category_name(len(full)),
+        ),
     )
 
 
-@tracer.wrap()
-async def safe_create_invite(
-    channel: discord.VoiceChannel,
-    guild_xid: int,
-    max_age: int = 0,
-) -> Optional[str]:
-    if span := tracer.current_span():  # pragma: no cover
-        span.set_tags({"guild_xid": str(guild_xid), "channel_xid": str(channel.id)})
-
-    invite: Optional[str] = None
-    with suppress(
-        DiscordException,
-        log="int guild %(guild_xid)s, could create invite for channel %(channel_xid)s",
-        guild_xid=guild_xid,
-        channel_xid=channel.id,
-    ):
-        discord_invite = await channel.create_invite(max_age=max_age)
-        invite = str(discord_invite.url)
-    return invite
-
-
 @tracer.wrap()
 async def safe_delete_channel(
     channel: MessageableChannel,
@@ -337,12 +368,13 @@ async def safe_delete_channel(
     success = False
     with suppress(
         DiscordException,
+        ClientOSError,
         log="in guild %(guild_xid)s, could not delete channel %(channel_xid)s",
         guild_xid=guild_xid,
         channel_xid=channel_xid,
     ):
         try:
-            await channel.delete()  # type: ignore
+            await retry(lambda: channel.delete())  # type: ignore
             success = True
         except discord.errors.NotFound:
             logger.warning("in guild  %s, unknown channel %s", guild_xid, channel_xid)
@@ -366,12 +398,13 @@ async def safe_send_channel(
     message: Optional[discord.Message] = None
     with suppress(
         DiscordException,
+        ClientOSError,
         log="in guild %(guild_xid)s, could not send message to channel %(channel_xid)s",
         guild_xid=interaction.guild_id,
         channel_xid=interaction.channel_id,
     ):
-        await interaction.response.send_message(*args, **kwargs)
-        message = await interaction.original_response()
+        await retry(lambda: interaction.response.send_message(*args, **kwargs))
+        message = await retry(lambda: interaction.original_response())
     return message
 
 
@@ -397,12 +430,15 @@ async def safe_followup_channel(
     message: Optional[discord.Message] = None
     with suppress(
         DiscordException,
+        ClientOSError,
         log="in guild %(guild_xid)s, could not send message to channel %(channel_xid)s",
         guild_xid=interaction.guild_id,
         channel_xid=interaction.channel_id,
     ):
-        await interaction.followup.send(*args, **kwargs)
-        message = await interaction.original_response()
+        if "content" in kwargs and kwargs["content"] is None:
+            kwargs["content"] = MISSING
+        await retry(lambda: interaction.followup.send(*args, **kwargs))
+        message = await retry(lambda: interaction.original_response())
     return message
 
 
@@ -420,11 +456,12 @@ async def safe_channel_reply(
     message: Optional[discord.Message] = None
     with suppress(
         DiscordException,
+        ClientOSError,
         log="in guild %(guild_xid)s, could not reply to channel %(channel_xid)s",
         guild_xid=guild_xid,
         channel_xid=channel_xid,
     ):
-        message = await channel.send(*args, **kwargs)
+        message = await retry(lambda: channel.send(*args, **kwargs))
     return message
 
 
@@ -437,7 +474,7 @@ async def safe_message_reply(message: discord.Message, *args: Any, **kwargs: Any
         return
 
     try:
-        await message.reply(*args, **kwargs)
+        await retry(lambda: message.reply(*args, **kwargs))
     except Exception as ex:
         add_span_error(ex)
         logger.debug("debug: %s", ex, exc_info=True)
@@ -454,19 +491,19 @@ async def safe_send_user(
         span.set_tags({"user_xid": str(user_xid)})
 
     if user_xid in bad_users:
-        return log_warning("not sending to bad user %(user)s %(xid)s", user=user, xid=user.id)
+        return log_warning("not sending to bad user %(user)s %(xid)s", user=user, xid=user_xid)
 
     if not hasattr(user, "send"):
-        return log_warning("no send method on user %(user)s %(xid)s", user=user, xid=user.id)
+        return log_warning("no send method on user %(user)s %(xid)s", user=user, xid=user_xid)
 
     try:
-        await user.send(*args, **kwargs)
+        await retry(lambda: user.send(*args, **kwargs))
     except discord.errors.DiscordServerError as ex:
         add_span_error(ex)
         log_warning(
             "discord server error sending to user %(user)s %(xid)s",
             user=user,
-            xid=user.id,
+            xid=user_xid,
             exec_info=True,
         )
     except (discord.errors.Forbidden, discord.errors.HTTPException) as ex:
@@ -482,12 +519,20 @@ async def safe_send_user(
             return log_info(
                 "not allowed to send message to %(user)s %(xid)s",
                 user=user,
-                xid=user.id,
+                xid=user_xid,
             )
         log_warning(
             "failed to send message to user %(user)s %(xid)s",
             user=user,
-            xid=user.id,
+            xid=user_xid,
+            exec_info=True,
+        )
+    except ClientOSError as ex:
+        add_span_error(ex)
+        log_warning(
+            "client error sending to user %(user)s %(xid)s",
+            user=user,
+            xid=user_xid,
             exec_info=True,
         )
 
@@ -523,7 +568,8 @@ async def safe_add_role(
         )
         if not member or not hasattr(member, "roles"):
             logger.warning(
-                "warning: in guild %s, could not add role %s: could not find member: %s",
+                "warning: in guild %s (%s), could not manage role %s: could not find member: %s",
+                guild.name,
                 guild.id,
                 str(role),
                 str(user_or_member),
@@ -532,29 +578,35 @@ async def safe_add_role(
         discord_role = discord.utils.find(lambda m: m.name == role, guild.roles)
         if not discord_role:
             logger.warning(
-                "warning: in guild %s, could not add role: could not find role: %s",
+                "warning: in guild %s (%s), could not manage role: could not find role: %s",
+                guild.name,
                 guild.id,
                 str(role),
             )
             return
-        if not bot_can_role(guild):
+        if not bot_can_role(guild, discord_role):
             logger.warning(
-                "warning: in guild %s, could not add role: no permissions to add role: %s",
+                (
+                    "warning: in guild %s (%s), could not manage role:"
+                    " no permissions to manage role: %s"
+                ),
+                guild.name,
                 guild.id,
                 str(role),
             )
             return
         if remove:
-            await member.remove_roles(discord_role)
+            await retry(lambda: member.remove_roles(discord_role))
         else:
-            await member.add_roles(discord_role)
+            await retry(lambda: member.add_roles(discord_role))
     except (
         discord.errors.Forbidden,
         discord.errors.HTTPException,
     ) as ex:
         add_span_error(ex)
         logger.exception(
-            "warning: in guild %s, could not add role to member %s: %s",
+            "warning: in guild %s (%s), could not add role to member %s: %s",
+            guild.name,
             guild.id,
             str(user_or_member),
             ex,
