@@ -1,9 +1,9 @@
 from __future__ import annotations
 
 from datetime import datetime
-from typing import Any, Optional
+from typing import TYPE_CHECKING, Any, Optional
 
-import discord
+import pytz
 from asgiref.sync import sync_to_async
 from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import update
@@ -11,10 +11,14 @@ from sqlalchemy.sql.expression import update
 from ..database import DatabaseSession
 from ..models import Channel
 
+if TYPE_CHECKING:
+    from discord.abc import MessageableChannel
+
 
 class ChannelsService:
     @sync_to_async()
-    def upsert(self, channel: discord.TextChannel) -> dict[str, Any]:
+    def upsert(self, channel: MessageableChannel) -> dict[str, Any]:
+        assert channel.guild is not None
         name_max_len = Channel.name.property.columns[0].type.length  # type: ignore
         raw_name = getattr(channel, "name", "")
         name = raw_name[:name_max_len]
@@ -22,16 +26,16 @@ class ChannelsService:
             "xid": channel.id,
             "guild_xid": channel.guild.id,
             "name": name,
-            "updated_at": datetime.utcnow(),
+            "updated_at": datetime.now(tz=pytz.utc),
         }
         upsert = insert(Channel).values(**values)
         upsert = upsert.on_conflict_do_update(
             index_elements=[Channel.xid],
             index_where=Channel.xid == values["xid"],
-            set_=dict(
-                name=upsert.excluded.name,
-                updated_at=upsert.excluded.updated_at,
-            ),
+            set_={
+                "name": upsert.excluded.name,
+                "updated_at": upsert.excluded.updated_at,
+            },
         )
         DatabaseSession.execute(upsert, values)
         DatabaseSession.commit()
@@ -39,16 +43,16 @@ class ChannelsService:
         channel = DatabaseSession.query(Channel).filter(Channel.xid == channel.id).one()
         return channel.to_dict()
 
-    @sync_to_async
+    @sync_to_async()
     def forget(self, xid: int) -> None:
         DatabaseSession.query(Channel).filter(Channel.xid == xid).delete(synchronize_session=False)
 
-    @sync_to_async
+    @sync_to_async()
     def select(self, xid: int) -> Optional[dict[str, Any]]:
         channel = DatabaseSession.query(Channel).filter(Channel.xid == xid).one_or_none()
         return channel.to_dict() if channel else None
 
-    @sync_to_async
+    @sync_to_async()
     def set_default_seats(self, xid: int, seats: int) -> None:
         query = (
             update(Channel)
@@ -59,7 +63,7 @@ class ChannelsService:
         DatabaseSession.execute(query)
         DatabaseSession.commit()
 
-    @sync_to_async
+    @sync_to_async()
     def set_auto_verify(self, xid: int, setting: bool) -> None:
         query = (
             update(Channel)
@@ -70,7 +74,7 @@ class ChannelsService:
         DatabaseSession.execute(query)
         DatabaseSession.commit()
 
-    @sync_to_async
+    @sync_to_async()
     def set_verified_only(self, xid: int, setting: bool) -> None:
         query = (
             update(Channel)
@@ -81,7 +85,7 @@ class ChannelsService:
         DatabaseSession.execute(query)
         DatabaseSession.commit()
 
-    @sync_to_async
+    @sync_to_async()
     def set_unverified_only(self, xid: int, setting: bool) -> None:
         query = (
             update(Channel)
@@ -109,6 +113,23 @@ class ChannelsService:
         DatabaseSession.commit()
         return motd
 
+    @sync_to_async()
+    def set_extra(self, xid: int, message: Optional[str] = None) -> str:
+        if message:
+            max_len = Channel.extra.property.columns[0].type.length  # type: ignore
+            extra = message[:max_len]
+        else:
+            extra = ""
+        query = (
+            update(Channel)
+            .where(Channel.xid == xid)
+            .values(extra=extra)
+            .execution_options(synchronize_session=False)
+        )
+        DatabaseSession.execute(query)
+        DatabaseSession.commit()
+        return extra
+
     @sync_to_async()
     def set_voice_category(self, xid: int, value: str) -> str:
         max_len = Channel.voice_category.property.columns[0].type.length  # type: ignore
