@@ -24,7 +24,7 @@ class ConfigsService:
         )
         return config.to_dict() if config else None
 
-    @sync_to_async
+    @sync_to_async()
     def upsert(
         self,
         guild_xid: int,
@@ -43,7 +43,7 @@ class ConfigsService:
                 Config.guild_xid == values["guild_xid"],
                 Config.user_xid == values["user_xid"],
             ),
-            set_=dict(power_level=upsert.excluded.power_level),
+            set_={"power_level": upsert.excluded.power_level},
         )
         DatabaseSession.execute(upsert, values)
         DatabaseSession.commit()
