@@ -11,10 +11,9 @@ from ..models import Verify
 
 
 class VerifiesService:
-    def __init__(self):
-        self.current: Optional[Verify] = None
+    current: Optional[Verify] = None
 
-    @sync_to_async
+    @sync_to_async()
     def upsert(
         self,
         guild_xid: int,
@@ -37,7 +36,7 @@ class VerifiesService:
                     Verify.guild_xid == values["guild_xid"],
                     Verify.user_xid == values["user_xid"],
                 ),
-                set_=dict(verified=upsert.excluded.verified),
+                set_={"verified": upsert.excluded.verified},
             )
         DatabaseSession.execute(upsert, values)
         DatabaseSession.commit()
@@ -52,7 +51,7 @@ class VerifiesService:
             .one_or_none()
         )
 
-    @sync_to_async
+    @sync_to_async()
     def is_verified(self) -> bool:
         assert self.current
         return bool(self.current.verified)
