@@ -5,6 +5,7 @@ from datetime import datetime
 from os import getenv
 from typing import Optional
 
+import pytz
 from discord import Object
 from discord.abc import Snowflake
 
@@ -12,7 +13,7 @@ from .environment import running_in_pytest
 
 
 class Settings:
-    def __init__(self, guild_xid: Optional[int] = None):
+    def __init__(self, guild_xid: Optional[int] = None) -> None:
         self.guild_xid = guild_xid
 
         # content
@@ -53,11 +54,11 @@ class Settings:
             r"&permissions=2416045137"
             r"&scope=applications.commands%20bot"
         )
-        self.VOICE_INVITE_EXPIRE_TIME_S = 14400  # 4 hours
         self.EMBED_COLOR = 0x5A3EFD
         self.DATABASE_ECHO = False
         self.ADMIN_ROLE = "SpellBot Admin"
         self.MOD_PREFIX = "Moderator"
+        self.MAX_PENDING_GAMES = 5
 
         # tasks
         self.VOICE_GRACE_PERIOD_M = 10  # 10 minutes
@@ -68,11 +69,14 @@ class Settings:
         self.EXPIRE_TIME_M = 45  # 45 minutes
 
     def workaround_over_eager_caching(self, url: str) -> str:
-        return f"{url}?{datetime.today().strftime('%Y-%m-%d')}"
+        return f"{url}?{datetime.now(tz=pytz.utc).date().strftime('%Y-%m-%d')}"
+
+    def queer(self) -> bool:
+        return self.guild_xid == 757455940009328670 or datetime.now(tz=pytz.utc).month == 6
 
     @property
     def THUMB_URL(self) -> str:
-        if self.guild_xid == 757455940009328670:  # pragma: no cover
+        if self.queer():  # pragma: no cover
             return self.workaround_over_eager_caching(
                 "https://user-images.githubusercontent.com/1903876/"
                 "149257079-e3efe74f-482b-4410-a0ea-dd988a4d3c63.png",
@@ -83,7 +87,7 @@ class Settings:
 
     @property
     def ICO_URL(self) -> str:
-        if self.guild_xid == 757455940009328670:  # pragma: no cover
+        if self.queer():  # pragma: no cover
             return self.workaround_over_eager_caching(
                 "https://user-images.githubusercontent.com/1903876/"
                 "149257564-86595c81-82a5-4558-ae40-c03d29a95d1f.png",
