@@ -1,12 +1,13 @@
 from __future__ import annotations
 
 from .base_view import BaseView
-from .lfg_view import PendingGameView, StartedGameView
+from .lfg_view import PendingGameView, StartedGameSelect, StartedGameView
 from .setup_view import SetupView
 
 __all__ = [
     "BaseView",
     "PendingGameView",
     "SetupView",
+    "StartedGameSelect",
     "StartedGameView",
 ]
